@@ -591,9 +591,14 @@ void daisy::wheelEvent(QGraphicsSceneWheelEvent *event)
   
   else if ( m_type == QString("media_controller") )
   {
-    QProcess *myProcess = new QProcess(this);
-    if (delta < 0) {myProcess->start(getPlayerComs()[10]);}
-    else {myProcess->start(getPlayerComs()[9]);}
+    if (delta < 0)
+    {
+      KRun::runCommand( getPlayerComs()[10], 0, 0, NULL, NULL );
+    }
+    else
+    {
+      KRun::runCommand( getPlayerComs()[9], 0, 0, NULL, NULL );
+    }
   }
   
   else if ( m_type == QString("standard_dock") )
