@@ -434,74 +434,74 @@ void daisy::getLauncherValues()
     QStringList m_acoms_tmp;QStringList m_aicos_tmp;QStringList m_anames_tmp;QStringList m_iact_tmp;
     
     m_coms_tmp 
-    << QString("dolphin applications:/")
-    << QString("kfmclient exec file://$HOME") 
+    << QString("dolphin $HOME") 
     << QString("konsole") 
     << QString("opera") 
     << QString("kmail") 
     << QString("amarok -m") 
     << QString("kate") 
+    << QString("okular")
     << QString("systemsettings") 
     ;
     
     m_icos_tmp 
-    << QString("start-here-kde")
     << QString("user-home") 
     << QString("utilities-terminal") 
     << QString("applications-internet") 
     << QString("internet-mail") 
     << QString("amarok") 
     << QString("kate") 
+    << QString("graphics-viewer-document")
     << QString("preferences-system") 
     ;
     
     m_names_tmp 
-    << i18n("applications")
     << i18n("personal files") 
     << i18n("konsole") 
     << i18n("opera") 
     << i18n("kmail") 
     << i18n("amarok") 
     << i18n("kate") 
+    << i18n("Document viewer")
     << i18n("systemsettings") 
     ;
     
     m_acoms_tmp 
-    << QString("kfmclient exec bookmarks:/")
     << QString("kfmclient exec bookmarks:/") 
     << QString("ksysguard") 
     << QString("kfmclient exec bookmarks:/") 
     << QString("kfmclient exec mailto:/") 
     << QString("qdbus org.mpris.amarok /Player org.freedesktop.MediaPlayer.Pause") 
     << QString("okular") 
+    << QString("gwenview")
     << QString("kfmclient exec settings:/") 
     ;
     
     m_anames_tmp 
-    << i18n("bookmarks") 
     << i18n("bookmarks")
     << i18n("system") 
     << i18n("bookmarks") 
     << i18n("mail") 
     << i18n("pause") 
     << i18n("okular") 
+    << i18n("gwenview") 
     << i18n("settings") 
     ;
     
     m_aicos_tmp 
-    << QString("bookmarks") 
     << QString("bookmarks")
     << QString("utilities-system-monitor") 
     << QString("bookmarks") 
     << QString("email") 
     << QString("media-playback-pause") 
     << QString("okular") 
+    << QString("gwenview") 
     << QString("configure") 
     ;
     
     m_iact_tmp 
     << QString("0") 
-    << QString("1") 
+    << QString("0") 
     << QString("0") 
     << QString("0") 
     << QString("0") 
@@ -511,13 +511,13 @@ void daisy::getLauncherValues()
     ;
     
     m_alias_tmp 
-    << QString("dolphin")
-    << QString("konqueror") 
+    << QString("dolphin") 
     << QString("konsole") 
     << QString("opera") 
     << QString("kmail") 
     << QString("amarok") 
     << QString("kate") 
+    << QString("okular")
     << QString("systemsettings") 
     ;
     
