@@ -178,7 +178,8 @@ void daisy::createConfigurationInterface(KConfigDialog *parent)
     if ( m_player == QString("Amarok 1.x") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(0);
     else if ( m_player == QString("Amarok 2.x") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(1);
     else if ( m_player == QString("juK") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(2);
-    else if ( m_player == QString("XMMS") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(3);
+    else if ( m_player == QString("VLC") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(3);
+    else if ( m_player == QString("XMMS") )m_mainConfigurationUi.comboBox_player->setCurrentIndex(4);
     m_appearanceConfigurationUi.checkBox_indicons->setChecked(m_showindicons);
     
     
@@ -402,7 +403,8 @@ void daisy::configAccepted()
   if (m_box_index == 0) m_player = QString("Amarok 1.x");
   else if (m_box_index == 1) m_player = QString("Amarok 2.x");
   else if (m_box_index == 2) m_player = QString("juK");
-  else if (m_box_index == 3) m_player = QString("XMMS");
+  else if (m_box_index == 3) m_player = QString("VLC");
+  else if (m_box_index == 4) m_player = QString("XMMS");
   // Mouse over effects
   m_box_index = m_appearanceConfigurationUi.comboBoxIcoEffects->currentIndex();
   if (m_box_index == 0) m_zoomtype = QString("default");
