@@ -29,6 +29,7 @@
 
 //-----------------------------------------------------------------------------
 // Get the player commands
+// FIXME
 QStringList daisy::getPlayerComs()
 {
   QStringList m_player_coms;
@@ -73,7 +74,8 @@ QStringList daisy::getPlayerComs()
     QString("qdbus org.kde.juk /Player back")<<
     QString("qdbus org.kde.juk /Player forward")<<
     QString("qdbus org.kde.juk /Player seekBack")<<
-    QString("qdbus org.kde.juk /juk/MainWindow_1 com.trolltech.Qt.QWidget.show && qdbus org.kde.juk /juk/MainWindow_1 com.trolltech.Qt.QWidget.raise")<<
+    QString("qdbus org.kde.juk /juk/MainWindow_1 com.trolltech.Qt.QWidget.show && qdbus org.kde.juk /juk/MainWindow_1 \
+    com.trolltech.Qt.QWidget.raise")<<
     QString("qdbus org.kde.juk /Player seekForward")<< 
     QString("qdbus org.kde.juk /Player mute")<<
     QString("qdbus org.kde.juk /Player play")<<
@@ -81,6 +83,43 @@ QStringList daisy::getPlayerComs()
     QString("false");
   }
   
+  // FIXME Let me know of a better way to do this...
+  else if ( m_player == QString("VLC") )
+  {
+    m_player_coms <<
+    QString("dbus-send --print-reply --session --dest=org.mpris.vlc /Player org.freedesktop.MediaPlayer.Pause")<<
+    QString("dbus-send --print-reply --session --dest=org.mpris.vlc /Player org.freedesktop.MediaPlayer.Stop")<<
+    QString("dbus-send --print-reply --session --dest=org.mpris.vlc /Player org.freedesktop.MediaPlayer.Prev")<<
+    QString("dbus-send --print-reply --session --dest=org.mpris.vlc /Player org.freedesktop.MediaPlayer.Next")<<
+    QString("TOTALPOS=`qdbus org.mpris.vlc /Player GetMetadata | grep length`;\
+    TOTALPOS=`echo $TOTALPOS | sed 's/[length: ]//g'`;\
+    CURRENTPOS=`qdbus org.mpris.vlc /Player PositionGet`;\
+    TOTALPOS=`expr $TOTALPOS / 15`;\
+    TOSET=`expr $CURRENTPOS - $TOTALPOS`;\
+    action=`qdbus org.mpris.vlc /Player PositionSet $TOSET`;")<<
+    QString("vlc")<<
+    QString("TOTALPOS=`qdbus org.mpris.vlc /Player GetMetadata | grep length`;\
+    TOTALPOS=`echo $TOTALPOS | sed 's/[length: ]//g'`;\
+    CURRENTPOS=`qdbus org.mpris.vlc /Player PositionGet`;\
+    TOTALPOS=`expr $TOTALPOS / 15`;\
+    TOSET=`expr $TOTALPOS + $CURRENTPOS`;\
+    action=`qdbus org.mpris.vlc /Player PositionSet $TOSET`;")<<
+    QString("if [ ! `qdbus org.mpris.vlc /Player VolumeGet` = \"0\" ];then \
+    qdbus org.mpris.vlc /Player VolumeSet 0;else qdbus org.mpris.vlc /Player VolumeSet 15;fi")<<
+    QString("if [ -z `dbus-send --print-reply --session --dest=org.mpris.vlc /Player \
+    org.freedesktop.MediaPlayer.GetStatus | grep \"int32 2\"` ]; then \
+    dbus-send --print-reply --session --dest=org.mpris.vlc /Player \
+    org.freedesktop.MediaPlayer.Stop && sleep 1 && dbus-send --print-reply --session --dest=org.mpris.vlc /Player \
+    org.freedesktop.MediaPlayer.Play; else dbus-send --print-reply --session --dest=org.mpris.vlc /Player \
+    org.freedesktop.MediaPlayer.Play; fi")<<
+    QString("TOTALVOL=`qdbus org.mpris.vlc /Player VolumeGet`;\
+    TOSET=`expr $TOTALVOL + 2`;if [ ! $TOSET = 51 ];then if [ ! $TOSET = 52 ];\
+    then action=`qdbus org.mpris.vlc /Player VolumeSet $TOSET`;fi;fi;")<<
+    QString("TOTALVOL=`qdbus org.mpris.vlc /Player VolumeGet`;\
+    TOSET=`expr $TOTALVOL - 2`;if [ ! $TOSET = -1 ];then if [ ! $TOSET = -2 ];\
+    then action=`qdbus org.mpris.vlc /Player VolumeSet $TOSET`;fi;fi;");
+  }
+  
   else if ( m_player == QString("XMMS") )
   {
     m_player_coms<<
