@@ -2,6 +2,7 @@
 *   Tasks: daisy
 *   Description: a daisy for plasma
 *   Copyright (C) 2009,2010 by Lechio <Alessandros1pt@yahoo.com.br>
+*	Patch ligne 268: pierre.parent@insa-rouen.fr
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
@@ -263,7 +264,8 @@ void daisy::windowChanged(WId id, const unsigned long* properties )
 	#endif
       }
       
-      if ( m_tiptype == "thumbnail" || m_tiptype == "icon" )
+      //We need to check task_tmp actually exists before accessing its icon...
+      if ( (m_tiptype == "thumbnail" || m_tiptype == "icon") && task_tmp)
 	toolTipData.setImage( task_tmp->icon(32, 32, true) );
       Plasma::ToolTipManager::self()->setContent(m_widgets[m_alias.indexOf( widclass_tmp )], toolTipData);
     }
